Security Advisories (3)
CPANSA-Jifty-2011-01 (2011-03-17)

The path as passed in the fragment request data structure was used verbatim in the dispatcher and other locations. This possibly allowed requests to walk around ACLs by requesting '/some/safe/place/../../../dangerous' as a fragment.

CPANSA-Jifty-2009-01 (2009-04-09)

The REST plugin would let you call any method on the model.

CPANSA-Jifty-2008-01 (2009-04-08)

Allowed all actions on GET.

NAME

Jifty::Model::Session - Jifty session tracking

DESCRIPTION

Every Jifty application automatically inherits this table, which tracks session information for the application. Individual keys in the session structure are stored as rows, making session updates take constant time, and also reducing the need for locking.

table

Sessions are stored in the table _jifty_sessions.

since

Sessions first started getting stored in the database in Jifty version 0.60428

current_user

Everyone is treated as the superuser when dealing with session objects. This avoids infinite recursion, as otherwise it would try to look up the current user in the session object to find out who we are...

new_session_id

Returns a random new session id. This is a 32-character hex string.

create

Defaults the created and updated times to now.

set_value [VALUE]

Updates the updated column, in addition to setting the value.